"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.getScript = void 0;
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const exec_1 = require("@actions/exec");
const core = __importStar(require("@actions/core"));
const config = __importStar(require("./config"));
const coverage = __importStar(require("./coverage"));
const extensions = __importStar(require("./extensions"));
const tools = __importStar(require("./tools"));
const utils = __importStar(require("./utils"));
async function getScript(os) {
    const url = 'https://setup-php.com/support-ukraine';
    const filename = os + (await utils.scriptExtension(os));
    const script_path = path_1.default.join(__dirname, '../src/scripts', filename);
    const run_path = script_path.replace(os, 'run');
    process.env['fail_fast'] = await utils.getInput('fail-fast', false);
    const extension_csv = await utils.getInput('extensions', false);
    const ini_values_csv = await utils.getInput('ini-values', false);
    const coverage_driver = await utils.getInput('coverage', false);
    const tools_csv = await utils.getInput('tools', false);
    const version = await utils.parseVersion(await utils.readPHPVersion());
    const ini_file = await utils.parseIniFile(await utils.getInput('ini-file', false));
    let script = await utils.joins('.', script_path, version, ini_file);
    if (extension_csv) {
        script += await extensions.addExtension(extension_csv, version, os);
    }
    script += await tools.addTools(tools_csv, version, os);
    if (coverage_driver) {
        script += await coverage.addCoverage(coverage_driver, version, os);
    }
    if (ini_values_csv) {
        script += await config.addINIValues(ini_values_csv, os);
    }
    script += '\n' + (await utils.stepLog(`#StandWithUkraine`, os));
    script += '\n' + (await utils.addLog('$tick', 'read-more', url, os));
    fs_1.default.writeFileSync(run_path, script, { mode: 0o755 });
    return run_path;
}
exports.getScript = getScript;
async function run() {
    const os = process.platform;
    const tool = await utils.scriptTool(os);
    const run_path = await getScript(os);
    await (0, exec_1.exec)(tool + run_path);
}
exports.run = run;
(async () => {
    await run();
})().catch(error => {
    core.setFailed(error.message);
});
//# sourceMappingURL=install.js.map